scry.kaocha

In-process kaocha runner producing scry's inspectable result map.

Kaocha already captures per-test clojure.test events and (via its capture-output plugin) per-test output. This adapter runs kaocha programmatically and transforms its result tree into scry's result model.

Note: kaocha merges stdout and stderr into a single captured stream, so for kaocha results the combined output is placed in :out and :err is empty.

In-process kaocha runner producing scry's inspectable result map.

Kaocha already captures per-test clojure.test events and (via its
capture-output plugin) per-test output. This adapter runs kaocha
programmatically and transforms its result tree into scry's result model.

Note: kaocha merges stdout and stderr into a single captured stream, so for
kaocha results the combined output is placed in :out and :err is empty.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries